function r({model:i,el:e}){let n="_MOLS2GRID_"+i.get("grid_id");window[n]=i,i.on("change:filter_mask",()=>{g(i)}),e.classList.add("mols2grid-anywidget")}function g(i){let e=i.get("grid_id"),t;if(typeof window.mols2grid_lists<"u")t=window.mols2grid_lists[e];else if(typeof window.parent.mols2grid_lists<"u")t=window.parent.mols2grid_lists[e];else return;let n=i.get("filter_mask");n&&t.filter(function(d){return n[d.values()["mols2grid-id"]]})}var o={render:r};export{o as default};
